@@ -562,8 +562,8 @@ sub on_date {
 		   };
     $events{1} = { 8  => "The Company of the Ring reaches Hollin, 1419.\n",
 		   13 => "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n",
-		   14 => "The Company of the Ring spends the night in Moria hall 21, 1419.\n",
-		   15 => "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n",
+		   14 => "The Company of the Ring spends the night in Moria Hall 21, 1419.\n",
+		   15 => "The Bridge of Khazad-dum, and fall of Gandalf, 1419.\n",
 		   17 => "The Company of the Ring comes to Caras Galadhon at evening, 1419.\n",
 		   23 => "Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.\n",
 		   25 => "Gandalf casts down the Balrog, and passes away.\n" .
